# CreateSchedulerDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 
**workflow_id** | **str** |  | 
**schedule** | **str** |  | 
**parameters** | [**WorkflowTemplateParameters**](WorkflowTemplateParameters.md) |  | [optional] 
**job_key** | **str** |  | [optional] 
**last_run_at** | **datetime** |  | [optional] 
**next_run_at** | **datetime** |  | [optional] 
**is_paused** | **object** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

